/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000,2001  Alexander Pipelka

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Alexander Pipelka
    pipelka@teleweb.at

    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/05/21 12:18:06 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/include/Attic/pgrect.h,v $
    CVS/RCS Revision: $Revision: 1.1.2.5 $
    Status:           $State: Exp $
*/

#ifndef PG_RECT_H
#define PG_RECT_H

#ifdef SWIG
%include "swigcommon.h"
%module pglabel
%{
#include "pgrect.h"
%}
#endif

#include "paragui.h"

class DECLSPEC PG_Rect : public SDL_Rect {
public:

	PG_Rect(int x, int y, int w, int h);
	PG_Rect();
	PG_Rect(const PG_Rect& src);
	PG_Rect(const SDL_Rect& src);
	virtual ~PG_Rect();

	inline void SetRect(int x, int y, int w, int h) {
		my_xpos = x;
		my_ypos = y;
		my_width = w;
		my_height = h;
	}

	//virtual ~PG_Rect();

	PG_Rect& operator =(const PG_Rect& src);

	PG_Rect operator / (PG_Rect& b);

	SDL_Rect* SDLRect();

	/**
	Check if a given point is inside a rectangle (boxtest)

	@param	p		the point to test
	@param	r		the rectangle the point should be inside
	@return			true if the point is inside the rectangle
	*/
	static bool IsInside(const PG_Point& p, PG_Rect& r);

	/**
	Check if a given point is inside a rectangle (boxtest)

	@param	p		the point to test
	@return			true if the point is inside the rectangle
	*/
	bool IsInside(const PG_Point& p);

	/**
	Intersect two rectangles
	@param	p					reference rectangle
	@param	c					rectangle to intersect with reference
	@return						resulting intersection rectangle
	*/
	PG_Rect IntersectRect(const PG_Rect& p, const PG_Rect& c);

	/**
	Intersect two rectangles
	@param	p					rectangle to intersect with
	@return						resulting intersection rectangle
	*/
	PG_Rect IntersectRect(const PG_Rect& p);

	/**
	Return the width of the rectangle
	@return			width
	*/
	inline Uint16 Width() {
		return my_width;
	}

	/**
	Return the height of the rectangle
	@return			height
	*/
	inline Uint16 Height() {
		return my_height;
	}

	inline bool IsNull() {
		return (!Width() && !Height());
	}

	Sint16&	my_xpos;
	Sint16&	my_ypos;
	Uint16&	my_width;
	Uint16&	my_height;
};

#endif	// PG_RECT_H
